@@ -26,9 +26,9 @@
 {See the return value description}
 */
 
-#include "icrssdef.h"
+#include "rss.ih"
 
-int older(char const *lval, char const *rval)
+int rss_older(char const *lval, char const *rval)
 {
     struct stat
         lbuf,
